@@ -2,6 +2,7 @@
  *   Configuration for 6.2 - 6.4
  *   (the only difference to IRIX 5 is XFS and AFS support)
  *
+ *   If you use XFS with IRIX 6.2 you *must* install the latest xfs patch sets!
  *   For AFS support look at the end of this file
  */
 
@@ -12,6 +13,8 @@
 
 #include <sys/param.h>
 #include <sys/types.h>
+/* For IRIX 6.5.1 you might need the following hack */
+/* #define __SYS_SEMA_H__ */
 #include <sys/quota.h>
 #include <mntent.h>
 
@@ -41,19 +44,13 @@
 #define QS_BTIME dqb_btimelimit
 #define QS_FTIME dqb_ftimelimit
 
-/* with IRIX 6.2 you *must* install the latest xfs patch sets! */
+/* optional: for support of XFS file systems - comment out if not needed */
 #define IRIX_XFS
 
 
-/*
- *  If you have AFS (arla) uncomment the following define and MAKE lines
- */
-
-/* #define AFSQUOTA */
-
-/* MakeMaker parameters - do not remove!
-#MAKE AFSHOME=/products/security/athena
-#MAKE LDLOADLIBS=-L$(AFSHOME)/lib -lkafs -ldes -lkrb -Wl,-rpath -Wl,$(AFSHOME)/lib -lrpcsvc
-#MAKE INC=-I$(AFSHOME)/include
-#MAKE OBJ=afsquota.o
+/* MakeMaker parameters for AFS support - do not remove!
+MAKE AFSHOME=/products/security/athena
+MAKE LDLOADLIBS=-L$(AFSHOME)/lib32 -lkafs -ldes -lkrb -rpath $(AFSHOME)/lib32 -lrpcsvc
+MAKE INC=-I$(AFSHOME)/include
+MAKE OBJ=afsquota.o
 */
